===============================
Jump Detection for Uneven Ramps
===============================

.. note::

    This version of jump detection will work on both unevenly-spaced and
    evenly-spaced ramps. So there is no need to worry about which type of
    of ramp you have.

Description
-----------
This "step" is actually integrated into the :ref:`unevenly-spaced ramp fitting algorithm<rampfit-algorithm-ols22>`.
